# pyotita

A Python-based Code Quality Checker

The Greek word for "quality" is "ποιότητα" (pronounced "piotita").

## Overview

`pyotita` is a code quality assessment tool designed to help developers maintain high standards in their codebases.

## To Do
...